@@ -1,5 +1,5 @@
 package ExtUtils::HasCompiler;
-$ExtUtils::HasCompiler::VERSION = '0.022';
+$ExtUtils::HasCompiler::VERSION = '0.024';
 use strict;
 use warnings;
 
@@ -10,10 +10,10 @@ our %EXPORT_TAGS = (all => \@EXPORT_OK);
 use Config;
 use Carp 'carp';
 use File::Basename 'basename';
-use File::Spec::Functions qw/catfile catdir rel2abs/;
+use File::Spec::Functions qw/catfile catdir rel2abs curdir/;
 use File::Temp qw/tempdir tempfile/;
 
-my $tempdir = tempdir('HASCOMPILERXXXX', CLEANUP => 1, DIR => '.');
+my $tempdir = tempdir('HASCOMPILERXXXX', CLEANUP => 1, DIR => rel2abs(curdir));
 
 my $loadable_object_format = <<'END';
 #define PERL_NO_GET_CONTEXT
@@ -100,6 +100,7 @@ sub can_compile_loadable_object {
 	}
 	else {
 		my @extra;
+		my $inc = qq{"-I$incdir"};
 		if ($^O eq 'MSWin32') {
 			my $lib = '-l' . ($libperl =~ /lib([^.]+)\./)[0];
 			push @extra, "$abs_basename.def", $lib, $perllibs;
@@ -114,7 +115,10 @@ sub can_compile_loadable_object {
 		elsif ($^O eq 'android') {
 			push @extra, qq{"-L$incdir"}, '-lperl', $perllibs;
 		}
-		push @commands, qq{$cc $ccflags $optimize "-I$incdir" $cccdlflags -c $source_name -o $object_file};
+		elsif ($^O eq 'darwin' && $config->get('perlpath') eq '/usr/bin/perl' && ($config->get('osvers') =~ /(\d+)/)[0] >= 18) {
+			$inc = qq{-iwithsysroot "$incdir"};
+		}
+		push @commands, qq{$cc $ccflags $optimize $inc $cccdlflags -c $source_name -o $object_file};
 		push @commands, qq{$ld $object_file -o $loadable_object $lddlflags @extra};
 	}
 
@@ -222,7 +226,7 @@ ExtUtils::HasCompiler - Check for the presence of a compiler
 
 =head1 VERSION
 
-version 0.022
+version 0.024
 
 =head1 SYNOPSIS
 
@@ -292,7 +296,7 @@ This will force the linktype to be either static or dynamic. Dynamic compilation
 
 =head1 AUTHOR
 
-Leon Timmermans <leont@cpan.org>
+Leon Timmermans <fawaka@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
